@@ -8,6 +8,10 @@ def make(env_id: EnvId):
         from pgx.tic_tac_toe import TicTacToe
 
         return TicTacToe()
+    elif env_id == "shogi/v0":
+        from pgx.shogi import Shogi
+
+        return Shogi()
     elif env_id == "minatar/asterix/v0":
         from pgx.minatar.asterix import MinAtarAsterix
 
