@@ -8,7 +8,7 @@ from pgx.backgammon import (
     _calc_win_score,
     _change_turn,
     _is_action_legal,
-    _is_all_on_homeboad,
+    _is_all_on_home_board,
     _is_open,
     _legal_action_mask,
     _move,
@@ -20,11 +20,25 @@ from pgx.backgammon import (
     _distance_to_goal,
     _is_turn_end,
     _no_winning_step,
-    _normal_step
 )
 
 seed = 1701
 rng = jax.random.PRNGKey(seed)
+init = jax.jit(init)
+step = jax.jit(step)
+observe = jax.jit(observe)
+_no_winning_step = jax.jit(_no_winning_step)
+_calc_src = jax.jit(_calc_src)
+_calc_tgt = jax.jit(_calc_tgt)
+_calc_win_score = jax.jit(_calc_win_score)
+_change_turn = jax.jit(_change_turn)
+_is_action_legal = jax.jit(_is_action_legal)
+_is_all_on_home_board = jax.jit(_is_all_on_home_board)
+_is_open = jax.jit(_is_open)
+_legal_action_mask = jax.jit(_legal_action_mask)
+_move = jax.jit(_move)
+_rear_distance = jax.jit(_rear_distance)
+
 
 
 def make_test_boad():
@@ -92,6 +106,8 @@ def test_init():
 
 def test_init_roll():
     a = _roll_init_dice(rng)
+    assert len(a) == 2
+    assert a[0] != a[1]
 
 
 def test_is_turn_end():
@@ -164,6 +180,7 @@ def test_continual_pass():
     # 連続パスが可能かテスト
     # 白のdance
     board: jnp.ndarray = make_test_boad()
+    legal_action_mask = _legal_action_mask(board, jnp.int16(1), jnp.array([0, 1, -1, -1], dtype=jnp.int16))
     state = make_test_state(
         curr_player=jnp.int16(1),
         rng=rng,
@@ -172,10 +189,12 @@ def test_continual_pass():
         dice=jnp.array([2, 2], dtype=jnp.int16),
         playable_dice=jnp.array([2, 2, 2, 2], dtype=jnp.int16),
         played_dice_num=jnp.int16(0),
+        legal_action_mask = legal_action_mask,
     )
     _, state, _ = step(state, 6 * (1) + 0)  # actionによらずターンが変わる.
     assert state.turn == jnp.int16(-1)  # ターンが変わっていることを確認
 
+
 def test_step():
     board: jnp.ndarray = make_test_boad()
     legal_action_mask = _legal_action_mask(board, jnp.int16(1), jnp.array([0, 1, -1, -1], dtype=jnp.int16))
@@ -205,7 +224,7 @@ def test_step():
     # 白がサイコロ2をplay 25(off)->22
     _, state, _ = step(state=state, action=(1) * 6 + 1)
     assert (
-        state.playable_dice - jnp.array([0, -1, -1, -1])
+        state.playable_dice - jnp.array([0, -1, -1, -1], dtype=jnp.int16)
     ).sum() == 0  # playable diceが正しく更新されているか
     assert state.played_dice_num == 1  # played diceが増えているか.
     assert state.turn == 1  # turnが変わっていないか.
@@ -321,10 +340,10 @@ def test_is_all_on_home_boad():
     board: jnp.ndarray = make_test_boad()
     # 黒
     turn: jnp.int16 = jnp.int16(-1)
-    assert _is_all_on_homeboad(board, turn)
+    assert _is_all_on_home_board(board, turn)
     # 白
     turn = jnp.int16(1)
-    assert not _is_all_on_homeboad(board, turn)
+    assert not _is_all_on_home_board(board, turn)
 
 
 def test_rear_distance():
